<?php
/*
Plugin Name: BlogIt!
Plugin URI: http://zero-one.ch/
Description: This Plugin allows you to define some more details for your iOS APP BlogIt.
Version: 1.0 - $Rev: 101 $
Author: Thomas Spycher
Author URI: zero-one
*/
 
require_once("ZeroOneBase.php");

/**
 * BlogIt class.
 * 
 * @extends ZeroOneBase
 */
class BlogIt extends ZeroOneBase {
	/**
	 * translationDomain
	 * 
	 * (default value: 'blogit')
	 * 
	 * @var string
	 * @access private
	 */
	private $translationDomain = 'blogit';
	
	/**
	 * name
	 * 
	 * (default value: 'BlogIt')
	 * 
	 * @var string
	 * @access private
	 */
	private $name = 'BlogIt';
	
	/**
	 * settings
	 * 
	 * (default value: array('BlogittemplatePicture', 'Blogittemplate'))
	 * 
	 * @var array
	 * @access private
	 */
	private $settings = array('BlogittemplatePicture', 'Blogittemplate', 'BlogitMaxPictureWidth', 'BlogitMaxPictureHeight');
	
	/**
	 * __construct function.
	 * 
	 * @access public
	 * @return void
	 */
	function __construct() {
		add_action( 'init', array(&$this, 'buildXML') );
		add_action( 'init', array(&$this, 'load_language') );
		add_action( 'admin_init', array(&$this, 'register_settings' ) );
		add_action( 'admin_menu', array(&$this, 'load_adminmenu') );
	}
	
	
	/**
	 * load_language function.
	 * 
	 * @access public
	 * @return void
	 */
	function load_language() {
		load_plugin_textdomain( $this->translationDomain, false, dirname( plugin_basename(__FILE__) ) . '/languages');
	}
	
	/**
	 * buildXML function.
	 * 
	 * @access public
	 * @return void
	 */
	public function buildXML() {
		if(array_key_exists('blogit', $_REQUEST) ) {
			header ("Content-Type:text/xml");  

			$xml = new DOMDocument();

			$base = $xml->appendChild($xml->createElement("blogit"));
			$base->setAttribute('host', $_SERVER['HTTP_HOST'] );
			$base->setAttribute('method', $_SERVER['REQUEST_METHOD'] );

			foreach($this->settings as $setting) {
				$oDataNode = $base->appendChild($xml->createElement($setting));
				$oDataNode->appendChild($xml->createCDATASection( get_option($setting) ));
			}
			
	  		$categories_checked = get_option('blogit_categories');
			$base_categories = $base->appendChild($xml->createElement("categories"));
			if(is_array( $categories_checked )) {
				foreach($categories_checked as $category) {
					$base_categories->appendChild($xml->createElement("category", $category));
				}
			}

			

			echo $xml->saveXML();
			exit;
		}
	}

	##! Admin Functions
	
	/**
	 * load_adminmenu function.
	 * 
	 * @access public
	 * @return void
	 */
	public function load_adminmenu() {
		// Admin Menu
		add_submenu_page('index.php', $this->name, $this->name, 10, $this->name,  array(&$this, 'load_options_page'));// ,plugins_url('/images/icon.png', __FILE__));
	}

	/**
	 * load_options_page function.
	 * 
	 * @access public
	 * @return void
	 */
	public function load_options_page() {			 
		?>
		<div class="wrap">
		<div id="icon-options-general" class="icon32"><br /></div>
		<h2><?php echo $this->name; ?> <?php _e('Settings',$this->translationDomain); ?></h2>
		<br />
		
			<!--<?php bloginfo('language'); ?>-->
		
		<div class="metabox-holder">
		
			<div class="postbox-container" style="width:75%;">
			<h2><?php _e('Templates',$this->translationDomain); ?></h2>
	
			<form method="post" action="options.php">
	   		    <?php settings_fields( $this->name ); ?>
			
			    <table class="form-table">
			   		<tbody>
			   		<?php $this->setting_templateHTML(); ?>
					<tr>
			    		<th scope="row" colspan="2">
			    			<p class="submit">
			    			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			    			</p>
						</th>
					</tr>
	
			   		</tbody>
			    </table>
			    
	
			
			</form>
			
			<h2><?php _e('Categories',$this->translationDomain); ?></h2>
			
			<p><?php _e('This Categories are used when a new post gets created with the BlogIt App.',$this->translationDomain); ?></p>
			<form method="post" action="">
		    <input type="hidden" name="submit-type" value="setcategories" />
	
			<table class="form-table">
				<tbody>
				<tr valign="top">
					<th scope="row">
						<label><?php _e('Check the categories you want to use:',$this->translationDomain); ?></label>
	
					</th>
					<td>
						<?php $this->setting_categories(); ?>
					</td>
				</tr>
				<tr>
			    	<th scope="row" colspan="2">
			    		<p class="submit">
			    		<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			    		</p>
					</th>
				</tr>
				</tbody>
			</table>
			</form>
			<div class="clear"></div>

			</div>
			<? $this->createAboutBoxes(); ?>

		</div>
			
		</div> 
		<?php
	}
	
	/**
	 * setting_templateHTML function.
	 * 
	 * @access private
	 * @return void
	 */
	private function setting_templateHTML() {
		?>
				<tr valign="top">
					<th scope="row">
						<label for="BlogittemplatePicture"><?php _e('Template HTML code for posts with a picture:',$this->translationDomain); ?></label>

					</th>
					<td>
						<textarea cols="60" rows="7" name="BlogittemplatePicture"><?php echo get_option('BlogittemplatePicture'); ?></textarea>
						<blockquote>
							<ul>
								<li><pre>%Text%</pre> <?php _e('Represents the text in the post body',$this->translationDomain); ?></li>
								<li><pre>%PictureURL%</pre> <?php _e('Gets replaced with the URL of the uploaded picture',$this->translationDomain); ?></li>
							</ul>
						</blockquote>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">
						<label for="Blogittemplate"><?php _e('Template HTML code for posts without a picture:',$this->translationDomain); ?></label>
					</th>
					<td>
						<textarea cols="60" rows="7" name="Blogittemplate"><?php echo get_option('Blogittemplate'); ?></textarea>
						<blockquote>
							<ul>
								<li><pre>%Text%</pre> <?php _e('Represents the text in the post body',$this->translationDomain); ?></li>
							</ul>
						</blockquote>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">
						<label for="BlogitMaxPictureWidth"><?php _e('Maximum picture width', $this->translationDomain); ?></label>
					</th>
					<td>
						<input type="text" name="BlogitMaxPictureWidth" value="<?php echo get_option('BlogitMaxPictureWidth'); ?>" />
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">
						<label for="BlogitMaxPictureHeight"><?php _e('Maximum picture height', $this->translationDomain); ?><br /><i> (<?php _e('does have priority', $this->translationDomain); ?>) </i></label>
					</th>
					<td>
						<input type="text" name="BlogitMaxPictureHeight" value="<?php echo get_option('BlogitMaxPictureHeight'); ?>" />
					</td>
				</tr>
		<?php
	}

	
	/**
	 * setting_categories function.
	 * 
	 * @access private
	 * @return void
	 */
	private function setting_categories() {
		//print_r(serialize($_REQUEST));
		if ( isset($_POST['submit-type']) && $_POST['submit-type'] == 'setcategories' ) {
			if ( is_array($_POST['categories'])) {
				$categories = $_POST['categories'];
				//print_r($categories);
				update_option('blogit_categories',$categories);
				 _e("Categories updated.",$this->translationDomain);
			} else {
				update_option('blogit_categories','');
				_e("Categories unset.",$this->translationDomain);
			}
		}
		$categories = get_categories(array('type'=>'post', 'hide_empty'=>0, 'orderby'=>'name')); 
  		$categories_checked = get_option('blogit_categories');	
  		foreach ($categories as $category) {
			if(is_array($categories_checked)) {
				if (in_array($category->cat_name, $categories_checked)) {
					$selected = " checked=\"checked\"";
				} else {
					$selected = "";
				}
			}
			echo '<li><input type="checkbox" '.$selected.' name="categories[]" value="'.$category->cat_name.'" id="'.$category->category_nicename.'"><label for="'.$category->category_nicename.'">'.$category->cat_name."</li>";

  		}

	}
	
	/**
	 * register_settings function.
	 * 
	 * @access public
	 * @return void
	 */
	function register_settings() {
		foreach($this->settings as $setting) {
			register_setting( $this->name , $setting );
		}
	}
	
	/**
	 * createAboutBoxes function.
	 * 
	 * @access public
	 * @return void
	 */
	function createAboutBoxes() {
		?>
		<div class="postbox-container" style="width:24%;">
			<div id="sidebar-sortables" class="meta-box-sortables ui-sortable">
				<div id="ZeroOne_AboutBox" class="postbox" style="display: block; ">
					<div class="handlediv" title="Zum umschalten klicken"><br></div>
					<h3 class="hndle"><span><?php _e('About',$this->translationDomain);?></span></h3>
					<div class="inside">
						<p style="margin: 10px; ">
							<?php _e('AboutText',$this->translationDomain);?>
						</p>
					</div>
				</div>
				<div id="ZeroOne_AppStore" class="postbox ">
					<div class="handlediv" title="Zum umschalten klicken"><br></div>
					<h3 class="hndle"><span><?php _e('App Store',$this->translationDomain);?></span></h3>
					<div class="inside">
						<p style="margin: 10px; "><?php _e('AppStoreText',$this->translationDomain);?><br />
						<a href="" target="_blank">
							<p align="center"><img src="<?php print '/wp-content/plugins/'.dirname( plugin_basename(__FILE__) ).'/app_store_badge.png'; ?>" alt="app_store_badge" width="214" height="70" /></p>
						</a>
						</p>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

}

$_blogit = new BlogIt();
?>
